Index — django-modeltrans 0.2.1 documentation

# Index

A | G | M | R | T

## A

ActiveLanguageMixin (class in modeltrans.admin)

## G

get_field_name() (modeltrans.fields.TranslatedVirtualField method) | get_language() (modeltrans.fields.TranslatedVirtualField method)

## M

MultilingualManager (class in modeltrans.manager) | MultilingualQuerySet (class in modeltrans.manager)

## R

RegistrationConfig (class in modeltrans.apps)

## T

TranslatedVirtualField (class in modeltrans.fields) | TranslationField (class in modeltrans.fields)